You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hama.apache.org by ed...@apache.org on 2010/10/12 04:55:08 UTC

svn commit: r1021600 - in /incubator/hama/trunk/src: java/org/apache/hama/zookeeper/QuorumPeer.java test/org/apache/hama/HamaClusterTestCase.java

Author: edwardyoon
Date: Tue Oct 12 02:55:08 2010
New Revision: 1021600

URL: http://svn.apache.org/viewvc?rev=1021600&view=rev
Log:
Trivial changes: I just edited some comments.

Modified:
    incubator/hama/trunk/src/java/org/apache/hama/zookeeper/QuorumPeer.java
    incubator/hama/trunk/src/test/org/apache/hama/HamaClusterTestCase.java

Modified: incubator/hama/trunk/src/java/org/apache/hama/zookeeper/QuorumPeer.java
URL: http://svn.apache.org/viewvc/incubator/hama/trunk/src/java/org/apache/hama/zookeeper/QuorumPeer.java?rev=1021600&r1=1021599&r2=1021600&view=diff
==============================================================================
--- incubator/hama/trunk/src/test/org/apache/hama/HamaClusterTestCase.java (original)
+++ incubator/hama/trunk/src/test/org/apache/hama/HamaClusterTestCase.java Tue Oct 12 02:55:08 2010
@@ -44,7 +44,7 @@ public abstract class HamaClusterTestCas
     // need to edit the config to add the ZooKeeper servers.
     this.zooKeeperCluster = new MiniZooKeeperCluster();
     int clientPort = this.zooKeeperCluster.startup(testDir);
-    conf.set("hbase.zookeeper.property.clientPort", Integer.toString(clientPort));
+    conf.set("hama.zookeeper.property.clientPort", Integer.toString(clientPort));
 
     // start the mini cluster
     this.cluster = new MiniBSPCluster(conf, groomServers);
--- incubator/hama/trunk/src/java/org/apache/hama/zookeeper/QuorumPeer.java (original)
+++ incubator/hama/trunk/src/java/org/apache/hama/zookeeper/QuorumPeer.java Tue Oct 12 02:55:08 2010
@@ -153,7 +153,7 @@ public class QuorumPeer implements Const
   /**
    * Make a Properties object holding ZooKeeper config equivalent to zoo.cfg.
    * If there is a zoo.cfg in the classpath, simply read it in. Otherwise parse
    * the corresponding config options from the HBase XML configs and generate
    * the appropriate ZooKeeper properties.
    * @param conf Configuration to read from.
    * @return Properties holding mappings representing ZooKeeper zoo.cfg file.
@@ -172,10 +172,10 @@ public class QuorumPeer implements Const
       }
     }
 
     // Otherwise, use the configuration options from HBase's XML files.
     Properties zkProperties = new Properties();
 
     // Directly map all of the hbase.zookeeper.property.KEY properties.
     for (Entry<String, String> entry : conf) {
       String key = entry.getKey();
       if (key.startsWith(ZK_CFG_PROPERTY)) {
@@ -210,9 +210,9 @@ public class QuorumPeer implements Const
   }
 
   /**
    * Parse ZooKeeper's zoo.cfg, injecting HBase Configuration variables in.
    * This method is used for testing so we can pass our own InputStream.
-   * @param conf HBaseConfiguration to use for injecting variables.
+   * @param conf Configuration to use for injecting variables.
    * @param inputStream InputStream to read from.
    * @return Properties parsed from config stream with variables substituted.
    * @throws IOException if anything goes wrong parsing config
@@ -248,7 +248,7 @@ public class QuorumPeer implements Const
         }
         if (substituteValue == null) {
           String msg = "variable " + variable + " not set in system property "
-                     + "or hbase configs";
+                     + "or hama configs";
           LOG.fatal(msg);
           throw new IOException(msg);
         }
@@ -258,7 +258,7 @@ public class QuorumPeer implements Const
         varEnd += VARIABLE_END_LENGTH;
         varStart = value.indexOf(VARIABLE_START, varEnd);
       }
       // Special case for 'hbase.cluster.distributed' property being 'true'
       if (key.startsWith("server.")) {
         if (conf.get(CLUSTER_DISTRIBUTED).equals(CLUSTER_IS_DISTRIBUTED) &&
             value.startsWith("localhost")) {
@@ -153,7 +153,7 @@ public class QuorumPeer implements Const
    * Make a Properties object holding ZooKeeper config equivalent to zoo.cfg.
    * If there is a zoo.cfg in the classpath, simply read it in. Otherwise parse
-   * the corresponding config options from the HBase XML configs and generate
+   * the corresponding config options from the Hama XML configs and generate
    * the appropriate ZooKeeper properties.
    * @param conf Configuration to read from.
@@ -172,10 +172,10 @@ public class QuorumPeer implements Const
     }
 
-    // Otherwise, use the configuration options from HBase's XML files.
+    // Otherwise, use the configuration options from Hama's XML files.
     Properties zkProperties = new Properties();
 
@@ -172,10 +172,10 @@ public class QuorumPeer implements Const
     Properties zkProperties = new Properties();
 
-    // Directly map all of the hbase.zookeeper.property.KEY properties.
+    // Directly map all of the hama.zookeeper.property.KEY properties.
     for (Entry<String, String> entry : conf) {
       String key = entry.getKey();
@@ -210,9 +210,9 @@ public class QuorumPeer implements Const
 
   /**
-   * Parse ZooKeeper's zoo.cfg, injecting HBase Configuration variables in.
+   * Parse ZooKeeper's zoo.cfg, injecting Hama Configuration variables in.
    * This method is used for testing so we can pass our own InputStream.
@@ -258,7 +258,7 @@ public class QuorumPeer implements Const
         varStart = value.indexOf(VARIABLE_START, varEnd);
       }
-      // Special case for 'hbase.cluster.distributed' property being 'true'
+      // Special case for 'hama.cluster.distributed' property being 'true'
       if (key.startsWith("server.")) {
         if (conf.get(CLUSTER_DISTRIBUTED).equals(CLUSTER_IS_DISTRIBUTED) &&

Modified: incubator/hama/trunk/src/test/org/apache/hama/HamaClusterTestCase.java
URL: http://svn.apache.org/viewvc/incubator/hama/trunk/src/test/org/apache/hama/HamaClusterTestCase.java?rev=1021600&r1=1021599&r2=1021600&view=diff
==============================================================================